@@ -43,7 +43,7 @@ from pypdf._crypt_providers import (
     rc4_encrypt,
 )
 
-from ._utils import b_, logger_warning
+from ._utils import logger_warning
 from .generic import (
     ArrayObject,
     ByteStringObject,
@@ -72,13 +72,15 @@ class CryptFilter:
         if isinstance(obj, ByteStringObject):
             data = self.str_crypt.encrypt(obj.original_bytes)
             obj = ByteStringObject(data)
-        if isinstance(obj, TextStringObject):
+        elif isinstance(obj, TextStringObject):
             data = self.str_crypt.encrypt(obj.get_encoded_bytes())
             obj = ByteStringObject(data)
         elif isinstance(obj, StreamObject):
             obj2 = StreamObject()
             obj2.update(obj)
-            obj2.set_data(self.stm_crypt.encrypt(b_(obj._data)))
+            obj2.set_data(self.stm_crypt.encrypt(obj._data))
+            for key, value in obj.items():  # Dont forget the Stream dict.
+                obj2[key] = self.encrypt_object(value)
             obj = obj2
         elif isinstance(obj, DictionaryObject):
             obj2 = DictionaryObject()  # type: ignore
@@ -86,7 +88,7 @@ class CryptFilter:
                 obj2[key] = self.encrypt_object(value)
             obj = obj2
         elif isinstance(obj, ArrayObject):
-            obj = ArrayObject(self.encrypt_object(x) for x in obj)  # type: ignore
+            obj = ArrayObject(self.encrypt_object(x) for x in obj)
         return obj
 
     def decrypt_object(self, obj: PdfObject) -> PdfObject:
@@ -94,7 +96,9 @@ class CryptFilter:
             data = self.str_crypt.decrypt(obj.original_bytes)
             obj = create_string_object(data)
         elif isinstance(obj, StreamObject):
-            obj._data = self.stm_crypt.decrypt(b_(obj._data))
+            obj._data = self.stm_crypt.decrypt(obj._data)
+            for key, value in obj.items():  # Dont forget the Stream dict.
+                obj[key] = self.decrypt_object(value)
         elif isinstance(obj, DictionaryObject):
             for key, value in obj.items():
                 obj[key] = self.decrypt_object(value)
@@ -184,6 +188,7 @@ class AlgV4:
 
         Returns:
             The u_hash digest of length key_size
+
         """
         a = _padding(password)
         u_hash = hashlib.md5(a)
@@ -239,6 +244,7 @@ class AlgV4:
 
         Returns:
             The RC4 key
+
         """
         a = _padding(owner_password)
         o_hash_digest = hashlib.md5(a).digest()
@@ -247,8 +253,7 @@ class AlgV4:
             for _ in range(50):
                 o_hash_digest = hashlib.md5(o_hash_digest).digest()
 
-        rc4_key = o_hash_digest[: key_size // 8]
-        return rc4_key
+        return o_hash_digest[: key_size // 8]
 
     @staticmethod
     def compute_O_value(rc4_key: bytes, user_password: bytes, rev: int) -> bytes:
@@ -262,12 +267,13 @@ class AlgV4:
 
         Returns:
             The RC4 encrypted
+
         """
         a = _padding(user_password)
         rc4_enc = rc4_encrypt(rc4_key, a)
         if rev >= 3:
             for i in range(1, 20):
-                key = bytes(bytearray(x ^ i for x in rc4_key))
+                key = bytes(x ^ i for x in rc4_key)
                 rc4_enc = rc4_encrypt(key, rc4_enc)
         return rc4_enc
 
@@ -293,10 +299,10 @@ class AlgV4:
 
         Returns:
             The value
+
         """
         if rev <= 2:
-            value = rc4_encrypt(key, _PADDING)
-            return value
+            return rc4_encrypt(key, _PADDING)
 
         """
         Algorithm 5: Computing the encryption dictionary’s U (user password) value.
@@ -327,7 +333,7 @@ class AlgV4:
         u_hash.update(id1_entry)
         rc4_enc = rc4_encrypt(key, u_hash.digest())
         for i in range(1, 20):
-            rc4_key = bytes(bytearray(x ^ i for x in key))
+            rc4_key = bytes(x ^ i for x in key)
             rc4_enc = rc4_encrypt(rc4_key, rc4_enc)
         return _padding(rc4_enc)
 
@@ -377,6 +383,7 @@ class AlgV4:
 
         Returns:
             The key
+
         """
         key = AlgV4.compute_key(
             user_password, rev, key_size, o_entry, P, id1_entry, metadata_encrypted
@@ -439,6 +446,7 @@ class AlgV4:
 
         Returns:
             bytes
+
         """
         rc4_key = AlgV4.compute_O_value_key(owner_password, rev, key_size)
 
@@ -447,7 +455,7 @@ class AlgV4:
         else:
             user_password = o_entry
             for i in range(19, -1, -1):
-                key = bytes(bytearray(x ^ i for x in rc4_key))
+                key = bytes(x ^ i for x in rc4_key)
                 user_password = rc4_decrypt(key, user_password)
         return AlgV4.verify_user_password(
             user_password,
@@ -522,6 +530,7 @@ class AlgV5:
 
         Returns:
             The key
+
         """
         password = password[:127]
         if (
@@ -531,8 +540,7 @@ class AlgV5:
             return b""
         iv = bytes(0 for _ in range(16))
         tmp_key = AlgV5.calculate_hash(R, password, o_value[40:48], u_value[:48])
-        key = aes_cbc_decrypt(tmp_key, iv, oe_value)
-        return key
+        return aes_cbc_decrypt(tmp_key, iv, oe_value)
 
     @staticmethod
     def verify_user_password(
@@ -552,6 +560,7 @@ class AlgV5:
 
         Returns:
             bytes
+
         """
         password = password[:127]
         if AlgV5.calculate_hash(R, password, u_value[32:40], b"") != u_value[:32]:
@@ -562,7 +571,7 @@ class AlgV5:
 
     @staticmethod
     def calculate_hash(R: int, password: bytes, salt: bytes, udata: bytes) -> bytes:
-        # from https://github.com/qpdf/qpdf/blob/main/libqpdf/QPDF_encryption.cc
+        # https://github.com/qpdf/qpdf/blob/main/libqpdf/QPDF_encryption.cc
         k = hashlib.sha256(password + salt + udata).digest()
         if R < 6:
             return k
@@ -601,6 +610,7 @@ class AlgV5:
 
         Returns:
             A boolean
+
         """
         b8 = b"T" if metadata_encrypted else b"F"
         p1 = struct.pack("<I", p) + b"\xff\xff\xff\xff" + b8 + b"adb"
@@ -654,6 +664,7 @@ class AlgV5:
 
         Returns:
             A tuple (u-value, ue value)
+
         """
         random_bytes = secrets.token_bytes(16)
         val_salt = random_bytes[:8]
@@ -698,6 +709,7 @@ class AlgV5:
 
         Returns:
             A tuple (O value, OE value)
+
         """
         random_bytes = secrets.token_bytes(16)
         val_salt = random_bytes[:8]
@@ -741,12 +753,12 @@ class AlgV5:
 
         Returns:
             The perms value
+
         """
         b8 = b"T" if metadata_encrypted else b"F"
         rr = secrets.token_bytes(4)
         data = struct.pack("<I", p) + b"\xff\xff\xff\xff" + b8 + b"adb" + rr
-        perms = aes_ecb_encrypt(key, data)
-        return perms
+        return aes_ecb_encrypt(key, data)
 
 
 class PasswordType(IntEnum):
@@ -755,7 +767,7 @@ class PasswordType(IntEnum):
     OWNER_PASSWORD = 2
 
 
-class EncryptAlgorithm(tuple, Enum):  # noqa: SLOT001
+class EncryptAlgorithm(tuple, Enum):  # type: ignore # noqa: SLOT001
     # V, R, Length
     RC4_40 = (1, 2, 40)
     RC4_128 = (2, 3, 128)
@@ -765,7 +777,7 @@ class EncryptAlgorithm(tuple, Enum):  # noqa: SLOT001
 
 
 class EncryptionValues:
-    O: bytes  # noqa
+    O: bytes  # noqa: E741
     U: bytes
     OE: bytes
     UE: bytes
@@ -794,6 +806,7 @@ class Encryption:
              encrypting embedded file streams that do not have their own
              crypt filter specifier.
         values: Additional encryption parameters.
+
     """
 
     def __init__(
@@ -810,7 +823,7 @@ class Encryption:
         EFF: str,
         values: Optional[EncryptionValues],
     ) -> None:
-        # See TABLE 3.18 Entries common to all encryption dictionaries
+        # §7.6.2, entries common to all encryption dictionaries
         # use same name as keys of encryption dictionaries entries
         self.V = V
         self.R = R
@@ -907,6 +920,7 @@ class Encryption:
         key_data = key[:n] + pack1 + pack2
         key_hash = hashlib.md5(key_data)
         rc4_key = key_hash.digest()[: min(n + 5, 16)]
+
         # for AES-128
         key_hash.update(b"sAlT")
         aes128_key = key_hash.digest()[: min(n + 5, 16)]
@@ -924,14 +938,14 @@ class Encryption:
     def _get_crypt(
         method: str, rc4_key: bytes, aes128_key: bytes, aes256_key: bytes
     ) -> CryptBase:
-        if method == "/AESV3":
-            return CryptAES(aes256_key)
         if method == "/AESV2":
             return CryptAES(aes128_key)
-        elif method == "/Identity":
+        if method == "/AESV3":
+            return CryptAES(aes256_key)
+        if method == "/Identity":
             return CryptIdentity()
-        else:
-            return CryptRC4(rc4_key)
+
+        return CryptRC4(rc4_key)
 
     @staticmethod
     def _encode_password(password: Union[bytes, str]) -> bytes:
@@ -1140,7 +1154,7 @@ class Encryption:
     def make(
         alg: EncryptAlgorithm, permissions: int, first_id_entry: bytes
     ) -> "Encryption":
-        alg_ver, alg_rev, key_bits = cast(tuple, alg)
+        alg_ver, alg_rev, key_bits = alg
 
         stm_filter, str_filter, ef_filter = "/V2", "/V2", "/V2"
 
